Top

    Garou Rim: Dawn Operation
    Joensuu, Finland
    June 29th 2019
    3R+F
    10 players
    Esa-Matti Smolander
    http://www.vekn.net/event-calendar/event/9292

    -- 1gw3.5 + 4vp in the final

    Deck Name: Parliament of Shadows precon with no changes.

    Finals Seating

    Esa-Matti Smolander (Lasombra Starter) --> Petrus Makkonen (Epikasta TGB) --> Simo Tiippana (Lydia + Al-Muntathir Trujah Toolbox) --> Aapo Järvelin (Theo + Beast anarch Rush) --> Petro Hirvonen (Hektor Toolbox)

    Crypt (12 cards, min=32, max=38, avg=8.67)
    ------------------------------------------
    2x Luca Italicus	 10  DOM FOR NEC OBT POT tha	archbishop  Lasombra:4
    2x Antón de Concepción	 9   ANI DOM OBT POT aus	archbishop  Lasombra:4
    2x Carolina Vález	 9   DOM OBT POT PRE aus	archbishop  Lasombra:5
    2x Charles Delmare	 8   DOM OBT POT cel		cardinal    Lasombra:5
    2x Lord Leopold Valdemar 8   OBT POT cel dom obf	priscus	    Lasombra:5
    2x Percival		 8   FOR OBT POT aus dom	archbishop  Lasombra:5

    Library (77 cards)
    Master (13; 4 trifle)
    1x Information Highway
    1x Jake Washington
    1x Monastery of Shadows
    1x Papillon
    1x Political Hunting Ground
    1x Power Structure
    1x Powerbase: Madrid
    4x Villein
    2x Zillah's Valley

    Action (8)
    6x Govern the Unaligned
    2x Under Siege

    Ally (1)
    1x Mylan Horseed

    Political Action (15)
    1x Anarchist Uprising
    1x Ancient Influence
    2x Banishment
    8x Kine Resources Contested
    1x Neonate Breach
    1x Political Stranglehold
    1x Reins of Power

    Action Modifier (24)
    2x Blanket of Night
    4x Conditioning
    4x Seduction
    4x Shadow Play
    4x Shroud of Absence
    4x Shroud of Night
    2x Tenebrous Form

    Reaction (10)
    4x Deflection
    2x Obedience
    2x On the Qui Vive
    2x Wake with Evening's Freshness

    Combat (6)
    3x Oubliette
    3x Shadow Body